AdjacentSystem

Enum AdjacentSystem 

pub enum AdjacentSystem {
Show 14 variants AvatureRecruiting, Ga4, Amplitude, GoogleTagManager, Hris, LaborScheduling, Payroll, MarketingAutomation, Ticketing, CallCenterTelephony, Reviews, EmailSmsMarketing, BusinessIntelligence, DataLake,
}
Adjacent enterprise system that can provide labor, revenue, marketing, or review evidence.

Variants



AvatureRecruiting

Avature recruiting operations signal for labor, capacity, or task planning.



Ga4

Ga4 operations signal for labor, capacity, or task planning.



Amplitude

Amplitude operations signal for labor, capacity, or task planning.



GoogleTagManager

Google tag manager operations signal for labor, capacity, or task planning.



Hris

Hris operations signal for labor, capacity, or task planning.



LaborScheduling

Labor scheduling source for staffing plans.



Payroll

Payroll source for labor-cost reconciliation.



MarketingAutomation

Marketing automation operations signal for labor, capacity, or task planning.



Ticketing

Ticketing operations signal for labor, capacity, or task planning.



CallCenterTelephony

Call center telephony operations signal for labor, capacity, or task planning.



Reviews

Reviews operations signal for labor, capacity, or task planning.



EmailSmsMarketing

Email sms marketing operations signal for labor, capacity, or task planning.



BusinessIntelligence

Reporting or BI data source.



DataLake

Data lake operations signal for labor, capacity, or task planning.