CapacityConstraintKind

Enum CapacityConstraintKind 

pub enum CapacityConstraintKind {
    RoomOrSuiteAvailability,
    PlayYardAvailability,
    GroomerSlotAvailability,
    TrainerAvailability,
    StaffRatio,
    PetTemperament,
    HolidayPeak,
    CheckInCheckoutBottleneck,
}
Constraint that limits capacity utilization or creates labor mismatch risk.

Variants



RoomOrSuiteAvailability

Room or suite availability operations signal for labor, capacity, or task planning.



PlayYardAvailability

Play yard availability operations signal for labor, capacity, or task planning.



GroomerSlotAvailability

Groomer slot availability operations signal for labor, capacity, or task planning.



TrainerAvailability

Trainer availability operations signal for labor, capacity, or task planning.



StaffRatio

Staff ratio operations signal for labor, capacity, or task planning.



PetTemperament

Pet temperament operations signal for labor, capacity, or task planning.



HolidayPeak

Holiday peak operations signal for labor, capacity, or task planning.



CheckInCheckoutBottleneck

Check in checkout bottleneck operations signal for labor, capacity, or task planning.