pub enum DataQualityIssue {
MissingPetVaccinationRecords,
IncompletePetProfiles,
DuplicateCustomers,
MissingTemperamentNotes,
OpenInvoices,
UnclosedReservations,
UnusedPackages,
StaffNotesTooVague,
InconsistentServiceNamingAcrossSites,
}Expand description
Portfolio-level hygiene issue type that can explain unreliable labor/read-model signals.
Variants
MissingPetVaccinationRecords
Missing pet vaccination records operations signal for labor, capacity, or task planning.
IncompletePetProfiles
Incomplete pet profiles operations signal for labor, capacity, or task planning.
DuplicateCustomers
Duplicate customers operations signal for labor, capacity, or task planning.
MissingTemperamentNotes
Missing temperament notes operations signal for labor, capacity, or task planning.
OpenInvoices
Open invoices operations signal for labor, capacity, or task planning.
UnclosedReservations
Unclosed reservations operations signal for labor, capacity, or task planning.
UnusedPackages
Unused packages operations signal for labor, capacity, or task planning.
StaffNotesTooVague
Staff notes too vague operations signal for labor, capacity, or task planning.
InconsistentServiceNamingAcrossSites
Inconsistent service naming across sites operations signal for labor, capacity, or task planning.