pub enum DaycareFormat {
AllDayPlay,
HalfDayPlay,
DayBoarding,
DayPlayPlusRoom,
CatIndividualPlaytime,
}Expand description
Daycare format whose eligibility and supervision needs affect staffing.
Variants
AllDayPlay
All day play operations signal for labor, capacity, or task planning.
HalfDayPlay
Half day play operations signal for labor, capacity, or task planning.
DayBoarding
Daytime boarding care with lodging-style supervision.
DayPlayPlusRoom
Day play plus room operations signal for labor, capacity, or task planning.
CatIndividualPlaytime
Cat individual playtime operations signal for labor, capacity, or task planning.