OperatingFunction

Enum OperatingFunction 

pub enum OperatingFunction {
    FrontDesk,
    CallCenter,
    GeneralManagers,
    AssistantGeneralManagers,
    RegionalOperations,
    Grooming,
    Training,
    Marketing,
    InformationTechnology,
}
Resort operating function whose workload can be reduced or coordinated by automation.

Variants



FrontDesk

Front desk operations signal for labor, capacity, or task planning.



CallCenter

Call center operations signal for labor, capacity, or task planning.



GeneralManagers

General managers operations signal for labor, capacity, or task planning.



AssistantGeneralManagers

Assistant general managers operations signal for labor, capacity, or task planning.



RegionalOperations

Regional operations operations signal for labor, capacity, or task planning.



Grooming

Grooming service line or care-note category.



Training

Training service line or care-note category.



Marketing

Marketing operations signal for labor, capacity, or task planning.



InformationTechnology

Information technology operations signal for labor, capacity, or task planning.