OptimizationOpportunity

Enum OptimizationOpportunity 

pub enum OptimizationOpportunity {
    DemandForecasting,
    NoShowPrediction,
    DynamicWaitlistFilling,
    CapacityRecommendation,
    AddOnRecommendation,
    HolidayPlanning,
    OverUnderStaffingAlert,
    RevenueOptimizationWithoutCareDegradation,
}
Labor, capacity, or revenue optimization lever supported by validated source facts.

Variants



DemandForecasting

Demand forecasting operations signal for labor, capacity, or task planning.



NoShowPrediction

No show prediction operations signal for labor, capacity, or task planning.



DynamicWaitlistFilling

Dynamic waitlist filling operations signal for labor, capacity, or task planning.



CapacityRecommendation

Capacity recommendation operations signal for labor, capacity, or task planning.



AddOnRecommendation

Add on recommendation operations signal for labor, capacity, or task planning.



HolidayPlanning

Holiday planning operations signal for labor, capacity, or task planning.



OverUnderStaffingAlert

Over under staffing alert operations signal for labor, capacity, or task planning.



RevenueOptimizationWithoutCareDegradation

Revenue optimization without care degradation operations signal for labor, capacity, or task planning.